@@ -6,18 +6,24 @@ pub mod accounts_cache;
 pub mod accounts_db;
 pub mod accounts_hash;
 pub mod accounts_index;
+pub mod accounts_update_notifier_interface;
 pub mod ancestors;
 pub mod append_vec;
 pub mod bank;
 pub mod bank_client;
 pub mod bank_forks;
 pub mod bank_utils;
+pub mod block_cost_limits;
 pub mod blockhash_queue;
 pub mod bloom;
 pub mod builtins;
 pub mod commitment;
 pub mod contains;
+pub mod cost_model;
+pub mod cost_tracker;
+pub mod cost_tracker_stats;
 pub mod epoch_stakes;
+pub mod execute_cost_table;
 pub mod genesis_utils;
 pub mod hardened_unpack;
 pub mod hashed_transaction;
